@@ -4,7 +4,7 @@ import os
 
 import tensorflow as tf
 
-from transformers_keras.adapters.abstract_adapter import zip_weights
+from transformers_keras.adapters import parse_pretrained_model_files
 from transformers_keras.adapters.albert_adapter import AlbertAdapter
 
 from .layers import MultiHeadAttention
@@ -288,6 +288,8 @@ class Albert(tf.keras.Model):
                  attention_dropout_rate=0.1,
                  epsilon=1e-12,
                  stddev=0.02,
+                 return_states=False,
+                 return_attention_weights=False,
                  **kwargs):
         kwargs.pop('name', None)
         super(Albert, self).__init__(name='albert', **kwargs)
@@ -324,14 +326,22 @@ class Albert(tf.keras.Model):
             name='pooler'
         )
 
+        self.return_states = return_states
+        self.return_attention_weights = return_attention_weights
+
     def call(self, inputs, training=None):
         input_ids, segment_ids, mask = unpack_inputs_3(inputs)
         mask = mask[:, tf.newaxis, tf.newaxis, :]
         embed = self.embedding(inputs=(input_ids, segment_ids), mode='embedding')
-        outputs, all_hidden_states, all_attn_weights = self.encoder(inputs=(embed, mask))
+        sequence_outputs, all_hidden_states, all_attn_weights = self.encoder(inputs=(embed, mask))
         # take [CLS]
-        pooled_output = self.pooler(outputs[:, 0])
-        return outputs, pooled_output, all_hidden_states, all_attn_weights
+        pooled_output = self.pooler(sequence_outputs[:, 0])
+        outputs = (sequence_outputs, pooled_output)
+        if self.return_states:
+            outputs += (all_hidden_states, )
+        if self.return_attention_weights:
+            outputs += (all_attn_weights, )
+        return outputs
 
     def dummy_inputs(self):
         input_ids = tf.constant([0] * 128, dtype=tf.int64, shape=(1, 128))
@@ -341,13 +351,15 @@ class Albert(tf.keras.Model):
 
     @classmethod
     def from_pretrained(cls, pretrained_model_dir, adapter=None, verbose=True, **kwargs):
+        config_file, ckpt, vocab_file = parse_pretrained_model_files(pretrained_model_dir)
         if not adapter:
             adapter = AlbertAdapter()
-        model_config, name_mapping, ckpt, vocab_file = adapter.adapte(pretrained_model_dir)
+        model_config = adapter.adapte_config(config_file, **kwargs)
+        model_config['return_states'] = kwargs.get('return_states', False)
+        model_config['return_attention_weights'] = kwargs.get('return_attention_weights', False)
         model = cls(**model_config)
         model(model.dummy_inputs())
-        weights_values = zip_weights(model, ckpt, name_mapping, verbose=verbose)
-        tf.keras.backend.batch_set_value(weights_values)
+        adapter.adapte_weights(model, model_config, ckpt, **kwargs)
         return model
 
 
